/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.orkut.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;
import com.google.common.primitives.UnsignedLong;

/**
 * Model definition for Activity.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Orkut API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Activity extends GenericJson {

  /**
   * Identifies who has access to see this activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Acl access;

  /**
   * The person who performed the activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private OrkutAuthorResource actor;

  /**
   * The ID for the activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of activity. Always orkut#activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Links to resources related to this activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OrkutLinkResource> links;

  static {
    // hack to force ProGuard to consider OrkutLinkResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutLinkResource.class);
  }

  /**
   * The activity's object.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("object")
  private OrkutObject orkutObject;

  /**
   * The time at which the activity was initially published.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime published;

  /**
   * Title of the activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The time at which the activity was last updated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * This activity's verb, indicating what action was performed. Possible values are: - add - User
   * added new content to profile or album, e.g. video, photo.  - post - User publish content to the
   * stream, e.g. status, scrap.  - update - User commented on an activity.  - make-friend - User
   * added a new friend.  - birthday - User has a birthday.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String verb;

  /**
   * Identifies who has access to see this activity.
   * The value returned may be {@code null}.
   */
  public Acl getAccess() {
    return access;
  }

  /**
   * Identifies who has access to see this activity.
   * The value set may be {@code null}.
   */
  public Activity setAccess(Acl access) {
    this.access = access;
    return this;
  }

  /**
   * The person who performed the activity.
   * The value returned may be {@code null}.
   */
  public OrkutAuthorResource getActor() {
    return actor;
  }

  /**
   * The person who performed the activity.
   * The value set may be {@code null}.
   */
  public Activity setActor(OrkutAuthorResource actor) {
    this.actor = actor;
    return this;
  }

  /**
   * The ID for the activity.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID for the activity.
   * The value set may be {@code null}.
   */
  public Activity setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of activity. Always orkut#activity.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of activity. Always orkut#activity.
   * The value set may be {@code null}.
   */
  public Activity setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Links to resources related to this activity.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutLinkResource> getLinks() {
    return links;
  }

  /**
   * Links to resources related to this activity.
   * The value set may be {@code null}.
   */
  public Activity setLinks(java.util.List<OrkutLinkResource> links) {
    this.links = links;
    return this;
  }

  /**
   * The activity's object.
   * The value returned may be {@code null}.
   */
  public OrkutObject getObject() {
    return orkutObject;
  }

  /**
   * The activity's object.
   * The value set may be {@code null}.
   */
  public Activity setObject(OrkutObject orkutObject) {
    this.orkutObject = orkutObject;
    return this;
  }

  /**
   * The time at which the activity was initially published.
   * The value returned may be {@code null}.
   */
  public DateTime getPublished() {
    return published;
  }

  /**
   * The time at which the activity was initially published.
   * The value set may be {@code null}.
   */
  public Activity setPublished(DateTime published) {
    this.published = published;
    return this;
  }

  /**
   * Title of the activity.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * Title of the activity.
   * The value set may be {@code null}.
   */
  public Activity setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * The time at which the activity was last updated.
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * The time at which the activity was last updated.
   * The value set may be {@code null}.
   */
  public Activity setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * This activity's verb, indicating what action was performed. Possible values are: - add - User
   * added new content to profile or album, e.g. video, photo.  - post - User publish content to the
   * stream, e.g. status, scrap.  - update - User commented on an activity.  - make-friend - User
   * added a new friend.  - birthday - User has a birthday.
   * The value returned may be {@code null}.
   */
  public String getVerb() {
    return verb;
  }

  /**
   * This activity's verb, indicating what action was performed. Possible values are: - add - User
   * added new content to profile or album, e.g. video, photo.  - post - User publish content to the
   * stream, e.g. status, scrap.  - update - User commented on an activity.  - make-friend - User
   * added a new friend.  - birthday - User has a birthday.
   * The value set may be {@code null}.
   */
  public Activity setVerb(String verb) {
    this.verb = verb;
    return this;
  }

  /**
   * The activity's object.
   */
  public static final class OrkutObject extends GenericJson {

    /**
     * The HTML-formatted content, suitable for display. When updating an activity's content, post the
     * changes to this property, using the value of originalContent as a starting point. If the update
     * is successful, the server adds HTML formatting and responds with this formatted content.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String content;

    /**
     * The list of additional items.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<OrkutActivityobjectsResource> items;

    static {
      // hack to force ProGuard to consider OrkutActivityobjectsResource used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(OrkutActivityobjectsResource.class);
    }

    /**
     * The type of the object affected by the activity. Clients can use this information to style the
     * rendered activity object differently depending on the content.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String objectType;

    /**
     * Comments in reply to this activity.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Replies replies;

    /**
     * The HTML-formatted content, suitable for display. When updating an activity's content, post the
     * changes to this property, using the value of originalContent as a starting point. If the update
     * is successful, the server adds HTML formatting and responds with this formatted content.
     * The value returned may be {@code null}.
     */
    public String getContent() {
      return content;
    }

    /**
     * The HTML-formatted content, suitable for display. When updating an activity's content, post the
     * changes to this property, using the value of originalContent as a starting point. If the update
     * is successful, the server adds HTML formatting and responds with this formatted content.
     * The value set may be {@code null}.
     */
    public OrkutObject setContent(String content) {
      this.content = content;
      return this;
    }

    /**
     * The list of additional items.
     * The value returned may be {@code null}.
     */
    public java.util.List<OrkutActivityobjectsResource> getItems() {
      return items;
    }

    /**
     * The list of additional items.
     * The value set may be {@code null}.
     */
    public OrkutObject setItems(java.util.List<OrkutActivityobjectsResource> items) {
      this.items = items;
      return this;
    }

    /**
     * The type of the object affected by the activity. Clients can use this information to style the
     * rendered activity object differently depending on the content.
     * The value returned may be {@code null}.
     */
    public String getObjectType() {
      return objectType;
    }

    /**
     * The type of the object affected by the activity. Clients can use this information to style the
     * rendered activity object differently depending on the content.
     * The value set may be {@code null}.
     */
    public OrkutObject setObjectType(String objectType) {
      this.objectType = objectType;
      return this;
    }

    /**
     * Comments in reply to this activity.
     * The value returned may be {@code null}.
     */
    public Replies getReplies() {
      return replies;
    }

    /**
     * Comments in reply to this activity.
     * The value set may be {@code null}.
     */
    public OrkutObject setReplies(Replies replies) {
      this.replies = replies;
      return this;
    }

    /**
     * Comments in reply to this activity.
     */
    public static final class Replies extends GenericJson {

      /**
       * The list of comments.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private java.util.List<Comment> items;

      static {
        // hack to force ProGuard to consider Comment used, since otherwise it would be stripped out
        // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
        com.google.api.client.util.Data.nullOf(Comment.class);
      }

      /**
       * Total number of comments.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key @JsonString
      private UnsignedLong totalItems;

      /**
       * URL for the collection of comments in reply to this activity.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String url;

      /**
       * The list of comments.
       * The value returned may be {@code null}.
       */
      public java.util.List<Comment> getItems() {
        return items;
      }

      /**
       * The list of comments.
       * The value set may be {@code null}.
       */
      public Replies setItems(java.util.List<Comment> items) {
        this.items = items;
        return this;
      }

      /**
       * Total number of comments.
       * The value returned may be {@code null}.
       */
      public UnsignedLong getTotalItems() {
        return totalItems;
      }

      /**
       * Total number of comments.
       * The value set may be {@code null}.
       */
      public Replies setTotalItems(UnsignedLong totalItems) {
        this.totalItems = totalItems;
        return this;
      }

      /**
       * URL for the collection of comments in reply to this activity.
       * The value returned may be {@code null}.
       */
      public String getUrl() {
        return url;
      }

      /**
       * URL for the collection of comments in reply to this activity.
       * The value set may be {@code null}.
       */
      public Replies setUrl(String url) {
        this.url = url;
        return this;
      }

    }
  }

}
